summaryrefslogtreecommitdiffstats
path: root/src/3rdparty/phonon/mmf/audiooutput.h
diff options
context:
space:
mode:
authorGareth Stockwell <gareth.stockwell@sosco.com>2009-08-21 10:39:36 (GMT)
committerGareth Stockwell <gareth.stockwell@sosco.com>2009-08-21 10:39:36 (GMT)
commit3f39d630d3dcc161c4a85127129274ca7ea857a2 (patch)
treeba726756cfdd87883fd546ff2f0e5c2b20e64eac /src/3rdparty/phonon/mmf/audiooutput.h
parent932c48658656fa328507b16e39c3a6cc820ef15e (diff)
downloadQt-3f39d630d3dcc161c4a85127129274ca7ea857a2.zip
Qt-3f39d630d3dcc161c4a85127129274ca7ea857a2.tar.gz
Qt-3f39d630d3dcc161c4a85127129274ca7ea857a2.tar.bz2
Further tidied up volume handling
Diffstat (limited to 'src/3rdparty/phonon/mmf/audiooutput.h')
-rw-r--r--src/3rdparty/phonon/mmf/audiooutput.h16
1 files changed, 7 insertions, 9 deletions
diff --git a/src/3rdparty/phonon/mmf/audiooutput.h b/src/3rdparty/phonon/mmf/audiooutput.h
index ad39626..38623a8 100644
--- a/src/3rdparty/phonon/mmf/audiooutput.h
+++ b/src/3rdparty/phonon/mmf/audiooutput.h
@@ -19,19 +19,19 @@ along with this library. If not, see <http://www.gnu.org/licenses/>.
#ifndef PHONON_MMF_AUDIOOUTPUT_H
#define PHONON_MMF_AUDIOOUTPUT_H
-#include <Phonon/audiooutputinterface.h>
+#include <phonon/audiooutputinterface.h>
namespace Phonon
{
namespace MMF
{
class Backend;
- class VolumeControlInterface;
+ class VolumeObserver;
/**
* @short AudioOutputInterface implementation for MMF.
*
* Forwards volume commands to the VolumeControlInterface instance,
* which is provided by the backend when MediaNode objects are
* connected.
*
@@ -70,19 +70,17 @@ namespace Phonon
/**
* Called by backend when nodes are connected.
*/
- void setVolumeControl(VolumeControlInterface *volumeControl);
+ void setVolumeObserver(VolumeObserver& observer);
Q_SIGNALS:
void volumeChanged(qreal volume);
void audioDeviceFailed();
private:
- /**
- * This value is used when m_volumeControl is NULL.
- */
- qreal m_volume;
+ qreal m_volume;
- VolumeControlInterface * m_volumeControl;
+ // Not owned
+ VolumeObserver* m_observer;
};
}
}
@@ -19,19 +19,19 @@ along with this library. If not, see <http://www.gnu.org/licenses/>.
* @short AudioOutputInterface implementation for MMF.
*
- * Forwards volume commands to the VolumeControlInterface instance,
+ * Forwards volume commands to the VolumeObserver instance,
* which is provided by the backend when MediaNode objects are
* connected.